@@ -10,9 +10,8 @@
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
-#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. DOI: 
-#'  \href{https://doi.org/10.1016/j.cageo.2020.104473}{10.1016/j.cageo.2020.104473}, 
-#'  URL: \url{http://sen2r.ranghetti.info/}.
+#'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
+#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{http://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @importFrom jsonlite fromJSON
 #' @export
@@ -34,7 +33,7 @@ load_binpaths <- function(bins = NULL) {
   
   # Define where the JSON with the paths is
   binpaths_file <- file.path(
-    if (dir.exists(normalize_path("~/.sen2r"))) {
+    if (dir.exists(normalize_path("~/.sen2r", mustWork = FALSE))) {
       normalize_path("~/.sen2r")
     } else {
       tempdir()
